==> jc-1.4.0.tar.gz: gnu/xml/dom/DomNode__24LiveNodeList.h <==
// final class gnu.xml.dom.DomNode$LiveNodeList

// class file dependencies
// @dep_class ff0bcc306cd936da gnu_xml_dom_DomNode__24LiveNodeList
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_dom_DomNode__24LiveNodeList_H_
#define _JC_gnu_xml_dom_DomNode__24LiveNodeList_H_

// Forward structure declarations
struct _jc_gnu_xml_dom_DomIterator$object;
struct _jc_gnu_xml_dom_DomNode$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_org_w3c_dom_Node$object;
struct _jc_org_w3c_dom_events_Event$object;

// Typedefs
typedef struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$sub_refs	_jc_gnu_xml_dom_DomNode__24LiveNodeList$sub_refs;
typedef struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$sub_nonrefs	_jc_gnu_xml_dom_DomNode__24LiveNodeList$sub_nonrefs;
typedef struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$refs	_jc_gnu_xml_dom_DomNode__24LiveNodeList$refs;
typedef struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$nonrefs	_jc_gnu_xml_dom_DomNode__24LiveNodeList$nonrefs;
typedef struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$object	_jc_gnu_xml_dom_DomNode__24LiveNodeList$object;

typedef const struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$vmethods	_jc_gnu_xml_dom_DomNode__24LiveNodeList$vmethods;
typedef const struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$vtable	_jc_gnu_xml_dom_DomNode__24LiveNodeList$vtable;
typedef const struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$vtype	_jc_gnu_xml_dom_DomNode__24LiveNodeList$vtype;

// Constructors
extern void _jc_gnu_xml_dom_DomNode__24LiveNodeList$method$_init$8f7e550af1d1e699(_jc_env *, struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$object *, struct _jc_gnu_xml_dom_DomNode$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern jshort _jc_gnu_xml_dom_DomNode__24LiveNodeList$method$acceptNode$b201c1e481e396cd(_jc_env *, struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$object *, struct _jc_object *);
extern struct _jc_gnu_xml_dom_DomIterator$object *_jc_gnu_xml_dom_DomNode__24LiveNodeList$method$createIterator$0102644307968666(_jc_env *, struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$object *);
extern void _jc_gnu_xml_dom_DomNode__24LiveNodeList$method$detach$fb5aad837a4c31d2(_jc_env *, struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$object *);
extern jint _jc_gnu_xml_dom_DomNode__24LiveNodeList$method$getLength$b9eaa8ec0a00f23d(_jc_env *, struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$object *);
extern void _jc_gnu_xml_dom_DomNode__24LiveNodeList$method$handleEvent$6446f0162cc6ebb5(_jc_env *, struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$object *, struct _jc_object *);
extern struct _jc_object *_jc_gnu_xml_dom_DomNode__24LiveNodeList$method$item$768348a8778b0a3e(_jc_env *, struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$object *, jint);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_dom_DomNode__24LiveNodeList$method_info$acceptNode$b201c1e481e396cd;
extern _jc_method _jc_gnu_xml_dom_DomNode__24LiveNodeList$method_info$createIterator$0102644307968666;
extern _jc_method _jc_gnu_xml_dom_DomNode__24LiveNodeList$method_info$detach$fb5aad837a4c31d2;
extern _jc_method _jc_gnu_xml_dom_DomNode__24LiveNodeList$method_info$getLength$b9eaa8ec0a00f23d;
extern _jc_method _jc_gnu_xml_dom_DomNode__24LiveNodeList$method_info$handleEvent$6446f0162cc6ebb5;
extern _jc_method _jc_gnu_xml_dom_DomNode__24LiveNodeList$method_info$item$768348a8778b0a3e;

// Virtual methods structure
struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$vmethods {
	jshort	(*acceptNode$b201c1e481e396cd)(_jc_env *, struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$object *, struct _jc_object *);
	struct _jc_gnu_xml_dom_DomIterator$object	*(*createIterator$0102644307968666)(_jc_env *, struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$object *);
	void	(*detach$fb5aad837a4c31d2)(_jc_env *, struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$object *);
	jint	(*getLength$b9eaa8ec0a00f23d)(_jc_env *, struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$object *);
	void	(*handleEvent$6446f0162cc6ebb5)(_jc_env *, struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$object *, struct _jc_object *);
	struct _jc_object	*(*item$768348a8778b0a3e)(_jc_env *, struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$object *, jint);
};

// Vtable
struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_dom_DomNode__24LiveNodeList$vmethods	gnu_xml_dom_DomNode__24LiveNodeList;
};

// Vtype
struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$vtype {
	_jc_type			type;
	_jc_gnu_xml_dom_DomNode__24LiveNodeList$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$sub_refs {
	struct _jc_java_lang_String$object	*elementURI;
	struct _jc_java_lang_String$object	*elementName;
	struct _jc_gnu_xml_dom_DomIterator$object	*current;
	struct _jc_gnu_xml_dom_DomNode$object	*this;
};

// Reference instance fields (object)
struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$refs {
    _jc_gnu_xml_dom_DomNode__24LiveNodeList$sub_refs	gnu_xml_dom_DomNode__24LiveNodeList;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$sub_nonrefs {
	jboolean	matchAnyURI;
	jboolean	matchAnyName;
	jint	lastIndex;
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_dom_DomNode__24LiveNodeList$sub_nonrefs	gnu_xml_dom_DomNode__24LiveNodeList;
};

// Object instance structure
struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$object {
	_jc_gnu_xml_dom_DomNode__24LiveNodeList$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_dom_DomNode__24LiveNodeList$vtype	*vtype;
	_jc_gnu_xml_dom_DomNode__24LiveNodeList$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_dom_DomNode__24LiveNodeList$vtype _jc_gnu_xml_dom_DomNode__24LiveNodeList$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_dom_DomNode__24LiveNodeList, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_dom_DomNode__24LiveNodeList$class_object;

#endif	/* _JC_gnu_xml_dom_DomNode__24LiveNodeList_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/dom/DomNode__24LiveNodeList.h <==
// final class gnu.xml.dom.DomNode$LiveNodeList

// class file dependencies
// @dep_class ff0bcc306cd936da gnu_xml_dom_DomNode__24LiveNodeList
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_dom_DomNode__24LiveNodeList_H_
#define _JC_gnu_xml_dom_DomNode__24LiveNodeList_H_

// Forward structure declarations
struct _jc_gnu_xml_dom_DomIterator$object;
struct _jc_gnu_xml_dom_DomNode$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_org_w3c_dom_Node$object;
struct _jc_org_w3c_dom_events_Event$object;

// Typedefs
typedef struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$sub_refs	_jc_gnu_xml_dom_DomNode__24LiveNodeList$sub_refs;
typedef struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$sub_nonrefs	_jc_gnu_xml_dom_DomNode__24LiveNodeList$sub_nonrefs;
typedef struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$refs	_jc_gnu_xml_dom_DomNode__24LiveNodeList$refs;
typedef struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$nonrefs	_jc_gnu_xml_dom_DomNode__24LiveNodeList$nonrefs;
typedef struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$object	_jc_gnu_xml_dom_DomNode__24LiveNodeList$object;

typedef const struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$vmethods	_jc_gnu_xml_dom_DomNode__24LiveNodeList$vmethods;
typedef const struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$vtable	_jc_gnu_xml_dom_DomNode__24LiveNodeList$vtable;
typedef const struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$vtype	_jc_gnu_xml_dom_DomNode__24LiveNodeList$vtype;

// Constructors
extern void _jc_gnu_xml_dom_DomNode__24LiveNodeList$method$_init$8f7e550af1d1e699(_jc_env *, struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$object *, struct _jc_gnu_xml_dom_DomNode$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jshort _jc_gnu_xml_dom_DomNode__24LiveNodeList$method$acceptNode$b201c1e481e396cd(_jc_env *, struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_gnu_xml_dom_DomIterator$object *_jc_gnu_xml_dom_DomNode__24LiveNodeList$method$createIterator$0102644307968666(_jc_env *, struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_dom_DomNode__24LiveNodeList$method$detach$fb5aad837a4c31d2(_jc_env *, struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_xml_dom_DomNode__24LiveNodeList$method$getLength$b9eaa8ec0a00f23d(_jc_env *, struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_dom_DomNode__24LiveNodeList$method$handleEvent$6446f0162cc6ebb5(_jc_env *, struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_xml_dom_DomNode__24LiveNodeList$method$item$768348a8778b0a3e(_jc_env *, struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$object *, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_dom_DomNode__24LiveNodeList$method_info$acceptNode$b201c1e481e396cd;
extern _jc_method _jc_gnu_xml_dom_DomNode__24LiveNodeList$method_info$createIterator$0102644307968666;
extern _jc_method _jc_gnu_xml_dom_DomNode__24LiveNodeList$method_info$detach$fb5aad837a4c31d2;
extern _jc_method _jc_gnu_xml_dom_DomNode__24LiveNodeList$method_info$getLength$b9eaa8ec0a00f23d;
extern _jc_method _jc_gnu_xml_dom_DomNode__24LiveNodeList$method_info$handleEvent$6446f0162cc6ebb5;
extern _jc_method _jc_gnu_xml_dom_DomNode__24LiveNodeList$method_info$item$768348a8778b0a3e;

// Virtual methods structure
struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$vmethods {
	jshort	(*acceptNode$b201c1e481e396cd)(_jc_env *, struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_gnu_xml_dom_DomIterator$object	*(*createIterator$0102644307968666)(_jc_env *, struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$object *) _JC_JCNI_ATTR;
	void	(*detach$fb5aad837a4c31d2)(_jc_env *, struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$object *) _JC_JCNI_ATTR;
	jint	(*getLength$b9eaa8ec0a00f23d)(_jc_env *, struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$object *) _JC_JCNI_ATTR;
	void	(*handleEvent$6446f0162cc6ebb5)(_jc_env *, struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*item$768348a8778b0a3e)(_jc_env *, struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$object *, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_dom_DomNode__24LiveNodeList$vmethods	gnu_xml_dom_DomNode__24LiveNodeList;
};

// Vtype
struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$vtype {
	_jc_type			type;
	_jc_gnu_xml_dom_DomNode__24LiveNodeList$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$sub_refs {
	struct _jc_java_lang_String$object	*elementURI;
	struct _jc_java_lang_String$object	*elementName;
	struct _jc_gnu_xml_dom_DomIterator$object	*current;
	struct _jc_gnu_xml_dom_DomNode$object	*this;
};

// Reference instance fields (object)
struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$refs {
    _jc_gnu_xml_dom_DomNode__24LiveNodeList$sub_refs	gnu_xml_dom_DomNode__24LiveNodeList;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$sub_nonrefs {
	jboolean	matchAnyURI;
	jboolean	matchAnyName;
	jint	lastIndex;
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_dom_DomNode__24LiveNodeList$sub_nonrefs	gnu_xml_dom_DomNode__24LiveNodeList;
};

// Object instance structure
struct _jc_gnu_xml_dom_DomNode__24LiveNodeList$object {
	_jc_gnu_xml_dom_DomNode__24LiveNodeList$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_dom_DomNode__24LiveNodeList$vtype	*vtype;
	_jc_gnu_xml_dom_DomNode__24LiveNodeList$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_dom_DomNode__24LiveNodeList$vtype _jc_gnu_xml_dom_DomNode__24LiveNodeList$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_dom_DomNode__24LiveNodeList, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_dom_DomNode__24LiveNodeList$class_object;

#endif	/* _JC_gnu_xml_dom_DomNode__24LiveNodeList_H_ */
